==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/sr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Todos" : "Подсетници",
    "Personal" : "Лично",
    "{actor} created calendar {calendar}" : "{actor} је направио календар {calendar}",
    "You created calendar {calendar}" : "Креирали сте календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} је обрисао календар {calendar}",
    "You deleted calendar {calendar}" : "Обрисали сте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} је ажурирао календар {calendar}",
    "You updated calendar {calendar}" : "Ажурирали сте календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} је поделио календар {calendar} са вама",
    "You shared calendar {calendar} with {user}" : "Поделили сте календар {calendar} са {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} је поделио календар {calendar} са {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} је укинуо дељење календара {calendar} са вама",
    "You unshared calendar {calendar} from {user}" : "Укинули сте дељење календара {calendar} са {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} је укинуо дељење календара {calendar} са {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} је укинуо дељење календара {calendar} од себе",
    "You shared calendar {calendar} with group {group}" : "Поделили сте календар {calendar} са групом {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} је поделио календар {calendar} са групом {group}",
    "You unshared calendar {calendar} from group {group}" : "Укинули сте дељење календара {calendar} са групом {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} је укинуо дељење календара {calendar} са групом {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} је направио догађај {event} у календару {calendar}",
    "You created event {event} in calendar {calendar}" : "Креирали сте догађај {event} у календару {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} је обрисао догађај {event} из календара {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Обрисали сте догађај {event} из календара {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} је ажурирао догађај {event} у календару {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ажурирали сте догађај {event} у календару {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} је направио подсетник {todo} у листи {calendar}",
    "You created todo {todo} in list {calendar}" : "Креирали сте подсетник {todo}  у листи {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} је обрисао подсетник {todo} из листе {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Обрисали сте подсетник {todo} из листе {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} је ажурирао подсетник {todo}  у листи {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ажурирали сте подсетник {todo} у листи {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} је обрисао подсетник {todo} из листе {calendar}",
    "You solved todo {todo} in list {calendar}" : "Маркирали сте подсетник {todo} као готов у листи {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} је поново отворио подсетник {todo} у листи {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Поново сте отворили подсетник {todo}  у листи {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Календар</strong> је измењен",
    "A calendar <strong>event</strong> was modified" : "<strong>Догађај</strong> из календара је измењен",
    "A calendar <strong>todo</strong> was modified" : "<strong>Подсетник</strong> из календара је измењен",
    "Contact birthdays" : "Рођендани контаката",
    "%s via %s" : "%s путем %s",
    "Invitation canceled" : "Позивница отказана",
    "Hello %s," : "Здраво %s,",
    "The meeting »%s« with %s was canceled." : "Састанак »%s« са  %s је отказан.",
    "Invitation updated" : "Позивница ажурирана",
    "The meeting »%s« with %s was updated." : "Састанак »%s« са %s је ажуриран.",
    "%s invited you to »%s«" : "%s Вас је позвао на »%s«",
    "When:" : "Време:",
    "Where:" : "Место:",
    "Description:" : "Опис:",
    "Link:" : "Веза:",
    "Contacts" : "Контакти",
    "Technical details" : "Технички детаљи",
    "Remote Address: %s" : "Удаљена адреса: %s",
    "Request ID: %s" : "ИД захтева: %s",
    "CalDAV server" : "CalDAV сервер",
    "Send invitations to attendees" : "Пошаљи позивницу учесницима",
    "Please make sure to properly set up the email settings above." : "Пазите да правилно подесите поставке е-поште изнад."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/sr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Todos" : "Подсетници",
    "Personal" : "Лично",
    "{actor} created calendar {calendar}" : "{actor} је направио календар {calendar}",
    "You created calendar {calendar}" : "Креирали сте календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} је обрисао календар {calendar}",
    "You deleted calendar {calendar}" : "Обрисали сте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} је ажурирао календар {calendar}",
    "You updated calendar {calendar}" : "Ажурирали сте календар {calendar}",
    "You shared calendar {calendar} as public link" : "Поделили сте календар {calendar} као јавну везу",
    "You removed public link for calendar {calendar}" : "Уклонили сте јавну везу за календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} је поделио календар {calendar} са вама",
    "You shared calendar {calendar} with {user}" : "Поделили сте календар {calendar} са {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} је поделио календар {calendar} са {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} је укинуо дељење календара {calendar} са вама",
    "You unshared calendar {calendar} from {user}" : "Укинули сте дељење календара {calendar} са {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} је укинуо дељење календара {calendar} са {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} је укинуо дељење календара {calendar} од себе",
    "You shared calendar {calendar} with group {group}" : "Поделили сте календар {calendar} са групом {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} је поделио календар {calendar} са групом {group}",
    "You unshared calendar {calendar} from group {group}" : "Укинули сте дељење календара {calendar} са групом {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} је укинуо дељење календара {calendar} са групом {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} је направио догађај {event} у календару {calendar}",
    "You created event {event} in calendar {calendar}" : "Креирали сте догађај {event} у календару {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} је обрисао догађај {event} из календара {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Обрисали сте догађај {event} из календара {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} је ажурирао догађај {event} у календару {calendar}",
    "You updated event {event} in calendar {calendar}" : "Ажурирали сте догађај {event} у календару {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} је направио подсетник {todo} у листи {calendar}",
    "You created todo {todo} in list {calendar}" : "Креирали сте подсетник {todo}  у листи {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} је обрисао подсетник {todo} из листе {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Обрисали сте подсетник {todo} из листе {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} је ажурирао подсетник {todo}  у листи {calendar}",
    "You updated todo {todo} in list {calendar}" : "Ажурирали сте подсетник {todo} у листи {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} је обрисао подсетник {todo} из листе {calendar}",
    "You solved todo {todo} in list {calendar}" : "Маркирали сте подсетник {todo} као готов у листи {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} је поново отворио подсетник {todo} у листи {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Поново сте отворили подсетник {todo}  у листи {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Календар</strong> је измењен",
    "A calendar <strong>event</strong> was modified" : "<strong>Догађај</strong> из календара је измењен",
    "A calendar <strong>todo</strong> was modified" : "<strong>Подсетник</strong> из календара је измењен",
    "Contact birthdays" : "Рођендани контаката",
    "%s via %s" : "%s путем %s",
    "Invitation canceled" : "Позивница отказана",
    "Hello %s," : "Здраво %s,",
    "The meeting »%s« with %s was canceled." : "Састанак »%s« са  %s је отказан.",
    "Invitation updated" : "Позивница ажурирана",
    "The meeting »%s« with %s was updated." : "Састанак »%s« са %s је ажуриран.",
    "%s invited you to »%s«" : "%s Вас је позвао на »%s«",
    "When:" : "Време:",
    "Where:" : "Место:",
    "Description:" : "Опис:",
    "Link:" : "Веза:",
    "Contacts" : "Контакти",
    "Technical details" : "Технички детаљи",
    "Remote Address: %s" : "Удаљена адреса: %s",
    "Request ID: %s" : "ИД захтева: %s",
    "CalDAV server" : "CalDAV сервер",
    "Send invitations to attendees" : "Пошаљи позивницу учесницима",
    "Please make sure to properly set up the email settings above." : "Пазите да правилно подесите поставке е-поште изнад.",
    "Automatically generate a birthday calendar" : "Аутоматски изгенериши календар рођендана",
    "Birthday calendars will be generated by a background job." : "Календари рођендана ће бити генерисани као позадински послови.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Зато можда неће бити видљиви баш одмах по укључивању, али ће се појавити после неког времена."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
